@@ -15,8 +15,6 @@
  */
 
 #include <php.h>
-#include <zend_smart_str.h>
-#include <ext/standard/php_var.h>
 #include <Zend/zend_interfaces.h>
 #include <Zend/zend_exceptions.h>
 
@@ -150,59 +148,6 @@ static PHP_METHOD(MongoDB_BSON_Int64, jsonSerialize)
 	ADD_ASSOC_INT64_AS_STRING(return_value, "$numberLong", intern->integer);
 }
 
-static PHP_METHOD(MongoDB_BSON_Int64, serialize)
-{
-	php_phongo_int64_t*  intern;
-	zval                 retval;
-	php_serialize_data_t var_hash;
-	smart_str            buf = { 0 };
-
-	PHONGO_PARSE_PARAMETERS_NONE();
-
-	intern = Z_INT64_OBJ_P(getThis());
-
-	array_init_size(&retval, 1);
-	ADD_ASSOC_INT64_AS_STRING(&retval, "integer", intern->integer);
-
-	PHP_VAR_SERIALIZE_INIT(var_hash);
-	php_var_serialize(&buf, &retval, &var_hash);
-	smart_str_0(&buf);
-	PHP_VAR_SERIALIZE_DESTROY(var_hash);
-
-	PHONGO_RETVAL_SMART_STR(buf);
-
-	smart_str_free(&buf);
-	zval_ptr_dtor(&retval);
-}
-
-static PHP_METHOD(MongoDB_BSON_Int64, unserialize)
-{
-	php_phongo_int64_t*    intern;
-	char*                  serialized;
-	size_t                 serialized_len;
-	zval                   props;
-	php_unserialize_data_t var_hash;
-
-	intern = Z_INT64_OBJ_P(getThis());
-
-	PHONGO_PARSE_PARAMETERS_START(1, 1)
-	Z_PARAM_STRING(serialized, serialized_len)
-	PHONGO_PARSE_PARAMETERS_END();
-
-	PHP_VAR_UNSERIALIZE_INIT(var_hash);
-	if (!php_var_unserialize(&props, (const unsigned char**) &serialized, (unsigned char*) serialized + serialized_len, &var_hash)) {
-		zval_ptr_dtor(&props);
-		phongo_throw_exception(PHONGO_ERROR_UNEXPECTED_VALUE, "%s unserialization failed", ZSTR_VAL(php_phongo_int64_ce->name));
-
-		PHP_VAR_UNSERIALIZE_DESTROY(var_hash);
-		return;
-	}
-	PHP_VAR_UNSERIALIZE_DESTROY(var_hash);
-
-	php_phongo_int64_init_from_hash(intern, HASH_OF(&props));
-	zval_ptr_dtor(&props);
-}
-
 static PHP_METHOD(MongoDB_BSON_Int64, __serialize)
 {
 	PHONGO_PARSE_PARAMETERS_NONE();
@@ -611,7 +556,7 @@ static HashTable* php_phongo_int64_get_properties(zend_object* object)
 
 void php_phongo_int64_init_ce(INIT_FUNC_ARGS)
 {
-	php_phongo_int64_ce                = register_class_MongoDB_BSON_Int64(php_phongo_json_serializable_ce, php_phongo_type_ce, zend_ce_serializable, zend_ce_stringable);
+	php_phongo_int64_ce                = register_class_MongoDB_BSON_Int64(php_phongo_json_serializable_ce, php_phongo_type_ce, zend_ce_stringable);
 	php_phongo_int64_ce->create_object = php_phongo_int64_create_object;
 
 	memcpy(&php_phongo_handler_int64, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
