@@ -127,17 +127,6 @@ static PHP_METHOD(MongoDB_Driver_Monitoring_CommandSucceededEvent, getRequestId)
 	RETVAL_STRING(request_id);
 }
 
-static PHP_METHOD(MongoDB_Driver_Monitoring_CommandSucceededEvent, getServer)
-{
-	php_phongo_commandsucceededevent_t* intern;
-
-	intern = Z_COMMANDSUCCEEDEDEVENT_OBJ_P(getThis());
-
-	PHONGO_PARSE_PARAMETERS_NONE();
-
-	phongo_server_init(return_value, &intern->manager, intern->server_id);
-}
-
 static PHP_METHOD(MongoDB_Driver_Monitoring_CommandSucceededEvent, getServiceId)
 {
 	php_phongo_commandsucceededevent_t* intern = Z_COMMANDSUCCEEDEDEVENT_OBJ_P(getThis());
@@ -180,10 +169,6 @@ static void php_phongo_commandsucceededevent_free_object(zend_object* object)
 
 	zend_object_std_dtor(&intern->std);
 
-	if (!Z_ISUNDEF(intern->manager)) {
-		zval_ptr_dtor(&intern->manager);
-	}
-
 	if (intern->reply) {
 		bson_destroy(intern->reply);
 	}
@@ -220,7 +205,7 @@ static HashTable* php_phongo_commandsucceededevent_get_debug_info(zend_object* o
 
 	intern   = Z_OBJ_COMMANDSUCCEEDEDEVENT(object);
 	*is_temp = 1;
-	array_init_size(&retval, 10);
+	array_init_size(&retval, 9);
 
 	ADD_ASSOC_STRING(&retval, "host", intern->host.host);
 	ADD_ASSOC_LONG_EX(&retval, "port", intern->host.port);
@@ -240,13 +225,6 @@ static HashTable* php_phongo_commandsucceededevent_get_debug_info(zend_object* o
 	snprintf(request_id, sizeof(request_id), "%" PRId64, intern->request_id);
 	ADD_ASSOC_STRING(&retval, "requestId", request_id);
 
-	{
-		zval server;
-
-		phongo_server_init(&server, &intern->manager, intern->server_id);
-		ADD_ASSOC_ZVAL_EX(&retval, "server", &server);
-	}
-
 	if (intern->has_service_id) {
 		zval service_id;
 
